==> apache-trafficcontrol-7.0.1.tar.gz: apache-trafficcontrol-7.0.1/cache-config/t3c-generate/plugin/hello_world.go <==
package plugin

/*
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

import (
	"github.com/apache/trafficcontrol/cache-config/t3cutil"
)

func init() {
	// AddPlugin(10000, Funcs{modifyFiles: hello})
}

const HelloPath = "/_hello_world"

// hello is an example "hello world" plugin. To test, create a Parameter assigned to the server you're running t3c-generate on, named "enable_hello_world", with the Config File "hello_world" and the value "true"
func hello(d ModifyFilesData) []t3cutil.ATSConfigFile {
	hasHelloParam := false
	for _, param := range d.TOData.ServerParams {
		if param.Name == "enable_hello_world" && param.ConfigFile == "hello_world" && param.Value == "true" {
			hasHelloParam = true
			break
		}
	}
	if !hasHelloParam {
		return d.Files
	}

	fi := t3cutil.ATSConfigFile{}

	fi.Text = "Hello, World!\n"
	fi.ContentType = "text/plain"
	fi.LineComment = ""
	fi.Name = "hello.txt"
	fi.Path = "/opt/trafficserver/etc/trafficserver/"

	d.Files = append(d.Files, fi)
	return d.Files
}

==> apache-trafficcontrol-8.0.1.tar.gz: apache-trafficcontrol-8.0.1/cache-config/t3c-generate/plugin/hello_world.go <==
package plugin

/*
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

import (
	"github.com/apache/trafficcontrol/v8/cache-config/t3cutil"
)

func init() {
	// AddPlugin(10000, Funcs{modifyFiles: hello})
}

const HelloPath = "/_hello_world"

// hello is an example "hello world" plugin. To test, create a Parameter assigned to the server you're running t3c-generate on, named "enable_hello_world", with the Config File "hello_world" and the value "true"
func hello(d ModifyFilesData) []t3cutil.ATSConfigFile {
	hasHelloParam := false
	for _, param := range d.TOData.ServerParams {
		if param.Name == "enable_hello_world" && param.ConfigFile == "hello_world" && param.Value == "true" {
			hasHelloParam = true
			break
		}
	}
	if !hasHelloParam {
		return d.Files
	}

	fi := t3cutil.ATSConfigFile{}

	fi.Text = "Hello, World!\n"
	fi.ContentType = "text/plain"
	fi.LineComment = ""
	fi.Name = "hello.txt"
	fi.Path = "/opt/trafficserver/etc/trafficserver/"

	d.Files = append(d.Files, fi)
	return d.Files
}
